==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/LastYearExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WrapperExpressionDescriptionMetadata } from "./WrapperExpressionDescriptionMetadata";
import { LastYearExpressionDescription } from "./LastYearExpressionDescription";
/**
 * @hidden
 */
export let LastYearExpressionDescriptionMetadata = /*@__PURE__*/ (() => {
    class LastYearExpressionDescriptionMetadata extends Base {
        static b(a) {
            if (LastYearExpressionDescriptionMetadata.a == null) {
                LastYearExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                LastYearExpressionDescriptionMetadata.c(LastYearExpressionDescriptionMetadata.a);
            }
            if (a.j(LastYearExpressionDescriptionMetadata.a)) {
                return;
            }
            a.y(LastYearExpressionDescriptionMetadata.a);
        }
        static c(a) {
            WrapperExpressionDescriptionMetadata.c(a);
        }
        static d(a) {
            LastYearExpressionDescriptionMetadata.b(a);
            a.aa("LastYearExpression", () => new LastYearExpressionDescription());
            a.z("LastYearExpression", LastYearExpressionDescriptionMetadata.a);
        }
    }
    LastYearExpressionDescriptionMetadata.$t = /*@__PURE__*/ markType(LastYearExpressionDescriptionMetadata, 'LastYearExpressionDescriptionMetadata');
    LastYearExpressionDescriptionMetadata.a = null;
    return LastYearExpressionDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/LastYearExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WrapperExpressionDescriptionMetadata } from "./WrapperExpressionDescriptionMetadata";
import { LastYearExpressionDescription } from "./LastYearExpressionDescription";
/**
 * @hidden
 */
export let LastYearExpressionDescriptionMetadata = /*@__PURE__*/ (() => {
    class LastYearExpressionDescriptionMetadata extends Base {
        static b(a) {
            if (LastYearExpressionDescriptionMetadata.a == null) {
                LastYearExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                LastYearExpressionDescriptionMetadata.c(LastYearExpressionDescriptionMetadata.a);
            }
            if (a.k(LastYearExpressionDescriptionMetadata.a)) {
                return;
            }
            a.aa(LastYearExpressionDescriptionMetadata.a);
        }
        static c(a) {
            WrapperExpressionDescriptionMetadata.c(a);
        }
        static d(a) {
            LastYearExpressionDescriptionMetadata.b(a);
            a.ac("LastYearExpression", () => new LastYearExpressionDescription());
            a.ab("LastYearExpression", LastYearExpressionDescriptionMetadata.a);
        }
    }
    LastYearExpressionDescriptionMetadata.$t = /*@__PURE__*/ markType(LastYearExpressionDescriptionMetadata, 'LastYearExpressionDescriptionMetadata');
    LastYearExpressionDescriptionMetadata.a = null;
    return LastYearExpressionDescriptionMetadata;
})();
